@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2002 Free Software Foundation, Inc.
+/* Copyright (C) 2000-2002, 2004 Free Software Foundation, Inc.
    This file is part of the GNU LIBICONV Library.
 
    The GNU LIBICONV Library is free software; you can redistribute it
@@ -27,6 +27,8 @@
 #include <iconv.h>
 #include <errno.h>
 
+#include "binary-io.h"
+
 int main (int argc, char* argv[])
 {
   const char* charset;
@@ -39,6 +41,10 @@ int main (int argc, char* argv[])
   }
   charset = argv[1];
 
+#if O_BINARY
+  SET_BINARY(fileno(stdout));
+#endif
+
   cd = iconv_open(charset,"UCS-4-INTERNAL");
   if (cd == (iconv_t)(-1)) {
     perror("iconv_open");
